Index: chrome/browser/extensions/extensions_service.h |
=================================================================== |
--- chrome/browser/extensions/extensions_service.h (revision 27027) |
+++ chrome/browser/extensions/extensions_service.h (working copy) |
@@ -102,10 +102,14 @@ |
return GetExtensionByIdInternal(id, true, false); |
} |
- // Retrieves a vector of all page actions, irrespective of which |
- // extension they belong to. |
- std::vector<PageAction*> GetPageActions() const; |
+ // Retrieves a vector of all page actions, irrespective of which extension |
+ // they belong to. |
+ std::vector<ContextualAction*> GetPageActions() const; |
+ // Retrieves a vector of all browser actions, irrespective of which extension |
+ // they belong to. |
+ std::vector<ContextualAction*> GetBrowserActions() const; |
+ |
// Install the extension file at |extension_path|. Will install as an |
// update if an older version is already installed. |
// For fresh installs, this method also causes the extension to be |
@@ -232,6 +236,11 @@ |
DictionaryValue* manifest, const std::string& id, |
const FilePath& path, Extension::Location location); |
+ // Retrieves a vector of all page actions or browser actions, irrespective of |
+ // which extension they belong to. |
+ std::vector<ContextualAction*> GetContextualActions( |
+ ContextualAction::ContextualActionType action_type) const; |
+ |
// The profile this ExtensionsService is part of. |
Profile* profile_; |